@@ -16,9 +16,7 @@
 #ifndef STATUSCONFIG_H
 #define STATUSCONFIG_H
 
-#define KDE3_SUPPORT
 #include <kcmodule.h>
-#undef KDE3_SUPPORT
 
 class QTabWidget;
 
