@@ -18,17 +18,16 @@
  *
  */
 
+#include <QString>
+#include <QDateTime>
+#include <QSize>
+#include <QRect>
+#include <QStringList>
+#include <QColor>
+
 #include "xmpp_xmlcommon.h"
 #include "xmpp_stanza.h"
 
-#include <qstring.h>
-#include <qdom.h>
-#include <qdatetime.h>
-#include <qsize.h>
-#include <qrect.h>
-#include <qstringlist.h>
-#include <qcolor.h>
-
 //----------------------------------------------------------------------------
 // XDomNodeList
 //----------------------------------------------------------------------------
@@ -269,14 +268,18 @@ QDomElement addCorrectNS(const QDomElement &e)
 
 	// find closest xmlns
 	QDomNode n = e;
-	while(!n.isNull() && !n.toElement().hasAttribute("xmlns"))
+	while(!n.isNull() && !n.toElement().hasAttribute("xmlns") && n.toElement().namespaceURI() == "" )
 		n = n.parentNode();
 	QString ns;
-	if(n.isNull() || !n.toElement().hasAttribute("xmlns"))
-		ns = "jabber:client";
-	else
+	if(n.isNull() || !n.toElement().hasAttribute("xmlns")){
+		if (n.toElement().namespaceURI () == ""){
+			ns = "jabber:client";
+		} else {
+			ns = n.toElement().namespaceURI();
+		}
+	} else {
 		ns = n.toElement().attribute("xmlns");
-
+	}
 	// make a new node
 	QDomElement i = e.ownerDocument().createElementNS(ns, e.tagName());
 
